# Authors

- Aldo Tobler: Main author (Semester Thesis)
- Sören Hedtke: Supervisor, Maintenance and Finalization, Author of Proof of Concept in MATLAB
- Pascal Bleuler: Additional Features, Maintenance and Finalization
- Christian M. Franck: Supervisor, Head of Laboratory
- Mikolaj Rybinski: Git support, Open Source Consulting